pub async fn get_readyz(
configuration: &Configuration,
) -> Result<String, Error<GetReadyzError>>Expand description
Checks if the service is ready to serve requests
pub async fn get_readyz(
configuration: &Configuration,
) -> Result<String, Error<GetReadyzError>>Checks if the service is ready to serve requests