post_v2_updates

Function post_v2_updates 

pub async fn post_v2_updates(
    configuration: &Configuration,
    get_updates_request: GetUpdatesRequest,
    limit: Option<i64>,
    stream_idle_timeout_ms: Option<i64>,
) -> Result<Vec<JsGetUpdatesResponse>, Error<PostV2UpdatesError>>
Read the ledger’s filtered update stream for the specified contents and filters. It returns the event types in accordance with the stream contents selected. Also the selection criteria for individual events depends on the transaction shape chosen. - ACS delta: a requesting party must be a stakeholder of an event for it to be included. - ledger effects: a requesting party must be a witness of an event for it to be included. Notice: This endpoint should be used for small results set. When number of results exceeded node configuration limit (http-list-max-elements-limit) there will be an error (413 Content Too Large) returned. Increasing this limit may lead to performance issues and high memory consumption. Consider using websockets (asyncapi) for better efficiency with larger results.