pub struct CreateCommand {
pub template_id: String,
pub create_arguments: Option<Value>,
}Expand description
CreateCommand : Create a new contract instance based on a template.
Fields
template_id: StringThe template of contract the client wants to create. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4. Required
create_arguments: Option<Value>The arguments required for creating a contract from this template. Required
Implementations
Sourceimpl CreateCommand
impl CreateCommand