pub struct DisclosedContract {
pub template_id: Option<String>,
pub contract_id: Option<String>,
pub created_event_blob: String,
pub synchronizer_id: Option<String>,
}Expand description
DisclosedContract : An additional contract that is used to resolve contract & contract key lookups.
Fields
template_id: Option<String>The template id of the contract. The identifier uses the package-id reference format. If provided, used to validate the template id of the contract serialized in the created_event_blob. Optional
contract_id: Option<String>The contract id If provided, used to validate the contract id of the contract serialized in the created_event_blob. Optional
created_event_blob: StringOpaque byte string containing the complete payload required by the Daml engine to reconstruct a contract not known to the receiving participant. Required: must be non-empty
synchronizer_id: Option<String>The ID of the synchronizer where the contract is currently assigned Optional
Implementations
Sourceimpl DisclosedContract
impl DisclosedContract
Sourcepub fn new(created_event_blob: String) -> DisclosedContract
pub fn new(created_event_blob: String) -> DisclosedContract
An additional contract that is used to resolve contract & contract key lookups.