EventFormat

Struct EventFormat 

pub struct EventFormat {
    pub filters_by_party: Option<HashMap<String, Filters>>,
    pub filters_for_any_party: Option<Box<Filters>>,
    pub verbose: Option<bool>,
}
EventFormat : A format for events which defines both which events should be included and what data should be computed and included for them. Note that some of the filtering behavior depends on the TransactionShape, which is expected to be specified alongside usages of EventFormat.

Fields

filters_by_party: Option<HashMap<String, Filters>>filters_for_any_party: Option<Box<Filters>>verbose: Option<bool>

If enabled, values served over the API will contain more information than strictly necessary to interpret the data. In particular, setting the verbose flag to true triggers the ledger to include labels for record fields. Optional

Implementations

Source

impl EventFormat

pub fn new() -> EventFormat

A format for events which defines both which events should be included and what data should be computed and included for them. Note that some of the filtering behavior depends on the TransactionShape, which is expected to be specified alongside usages of EventFormat.