pub struct GetTransactionByOffsetRequest {
pub offset: i64,
pub requesting_parties: Option<Vec<String>>,
pub transaction_format: Option<Box<TransactionFormat>>,
}Expand description
GetTransactionByOffsetRequest : Provided for backwards compatibility, it will be removed in the Canton version 3.5.0.
Fields
offset: i64The offset of the transaction being looked up. Must be a valid absolute offset (positive integer). Required
requesting_parties: Option<Vec<String>>Provided for backwards compatibility, it will be removed in the Canton version 3.5.0. The parties whose events the client expects to see. Events that are not visible for the parties in this collection will not be present in the response. Each element must be a valid PartyIdString (as described in value.proto). Optional for backwards compatibility for GetTransactionByOffset request: if defined transaction_format must be unset (falling back to defaults).
transaction_format: Option<Box<TransactionFormat>>Implementations
Sourceimpl GetTransactionByOffsetRequest
impl GetTransactionByOffsetRequest
Sourcepub fn new(offset: i64) -> GetTransactionByOffsetRequest
pub fn new(offset: i64) -> GetTransactionByOffsetRequest
Provided for backwards compatibility, it will be removed in the Canton version 3.5.0.