GetUpdatesRequest

Struct GetUpdatesRequest 

pub struct GetUpdatesRequest {
    pub begin_exclusive: i64,
    pub end_inclusive: Option<i64>,
    pub filter: Option<Box<TransactionFilter>>,
    pub verbose: Option<bool>,
    pub update_format: Option<Box<UpdateFormat>>,
    pub descending_order: Option<bool>,
}

Fields

begin_exclusive: i64

Exclusive lower bound offset of the requested ledger section (non-negative integer). The response will only contain transactions whose offset is strictly greater than this. If set to zero, the lower bound is set to the beginning of the ledger. If the participant has been pruned, this parameter must be greater or equal than the pruning offset. Required

end_inclusive: Option<i64>

Inclusive higher bound offset of the requested ledger section. If specified the response will only contain transactions whose offset is less than or equal to this. If not specified, - the descending_order must not be selected, - the stream will not terminate. Optional

filter: Option<Box<TransactionFilter>>verbose: Option<bool>

Provided for backwards compatibility, it will be removed in the Canton version 3.5.0. If enabled, values served over the API will contain more information than strictly necessary to interpret the data. In particular, setting the verbose flag to true triggers the ledger to include labels, record and variant type ids for record fields. Optional for backwards compatibility, if defined update_format must be unset

update_format: Option<Box<UpdateFormat>>descending_order: Option<bool>

If set, the stream will populate the elements in descending order. Optional

Implementations