pub struct JsCommands {Show 15 fields
pub commands: Vec<Command>,
pub command_id: String,
pub act_as: Vec<String>,
pub user_id: Option<String>,
pub read_as: Option<Vec<String>>,
pub workflow_id: Option<String>,
pub deduplication_period: Option<Box<DeduplicationPeriod>>,
pub min_ledger_time_abs: Option<String>,
pub min_ledger_time_rel: Option<Box<Duration>>,
pub submission_id: Option<String>,
pub disclosed_contracts: Option<Vec<DisclosedContract>>,
pub synchronizer_id: Option<String>,
pub package_id_selection_preference: Option<Vec<String>>,
pub prefetch_contract_keys: Option<Vec<PrefetchContractKey>>,
pub taps_max_passes: Option<i32>,
}Expand description
JsCommands : A composite command that groups multiple commands together.
Fields
commands: Vec<Command>Individual elements of this atomic command. Must be non-empty. Required: must be non-empty
command_id: StringUniquely identifies the command. The triple (user_id, act_as, command_id) constitutes the change ID for the intended ledger change, where act_as is interpreted as a set of party names. The change ID can be used for matching the intended ledger changes with all their completions. Must be a valid LedgerString (as described in value.proto). Required
act_as: Vec<String>Set of parties on whose behalf the command should be executed. If ledger API authorization is enabled, then the authorization metadata must authorize the sender of the request to act on behalf of each of the given parties. Each element must be a valid PartyIdString (as described in value.proto). Required: must be non-empty
user_id: Option<String>Uniquely identifies the participant user that issued the command. Must be a valid UserIdString (as described in value.proto). Required unless authentication is used with a user token. In that case, the token’s user-id will be used for the request’s user_id. Optional
read_as: Option<Vec<String>>Set of parties on whose behalf (in addition to all parties listed in act_as) contracts can be retrieved. This affects Daml operations such as fetch, fetchByKey, lookupByKey, exercise, and exerciseByKey. Note: A participant node of a Daml network can host multiple parties. Each contract present on the participant node is only visible to a subset of these parties. A command can only use contracts that are visible to at least one of the parties in act_as or read_as. This visibility check is independent from the Daml authorization rules for fetch operations. If ledger API authorization is enabled, then the authorization metadata must authorize the sender of the request to read contract data on behalf of each of the given parties. Optional: can be empty
workflow_id: Option<String>Identifier of the on-ledger workflow that this command is a part of. Must be a valid LedgerString (as described in value.proto). Optional
deduplication_period: Option<Box<DeduplicationPeriod>>min_ledger_time_abs: Option<String>Lower bound for the ledger time assigned to the resulting transaction. Note: The ledger time of a transaction is assigned as part of command interpretation. Use this property if you expect that command interpretation will take a considerate amount of time, such that by the time the resulting transaction is sequenced, its assigned ledger time is not valid anymore. Must not be set at the same time as min_ledger_time_rel. Optional
min_ledger_time_rel: Option<Box<Duration>>submission_id: Option<String>A unique identifier to distinguish completions for different submissions with the same change ID. Typically a random UUID. Applications are expected to use a different UUID for each retry of a submission with the same change ID. Must be a valid LedgerString (as described in value.proto). If omitted, the participant or the committer may set a value of their choice. Optional
disclosed_contracts: Option<Vec<DisclosedContract>>Additional contracts used to resolve contract & contract key lookups. Optional: can be empty
synchronizer_id: Option<String>Must be a valid synchronizer id Optional
package_id_selection_preference: Option<Vec<String>>The package-id selection preference of the client for resolving package names and interface instances in command submission and interpretation Optional: can be empty
prefetch_contract_keys: Option<Vec<PrefetchContractKey>>Fetches the contract keys into the caches to speed up the command processing. Should only contain contract keys that are expected to be resolved during interpretation of the commands. Keys of disclosed contracts do not need prefetching. Optional: can be empty
taps_max_passes: Option<i32>The maximum number of passes for the Topology-Aware Package Selection (TAPS). Higher values can increase the chance of successful package selection for routing of interpreted transactions. If unset, this defaults to the value defined in the participant configuration. The provided value must not exceed the limit specified in the participant configuration. Optional
Implementations