pub struct JsGetActiveContractsPageResponse {
pub active_contracts: Vec<JsGetActiveContractsResponse>,
pub active_at_offset: i64,
pub next_page_token: Option<String>,
}Fields
active_contracts: Vec<JsGetActiveContractsResponse>The collection of active contracts for this page response. Required: must be non-empty
active_at_offset: i64The active_at_offset which was specified in the request, or the calculated active_at_offset from the actual ledger end from at the evaluation of the request. Required
next_page_token: Option<String>If not present this is the last page. If present, this token must be used to get the next page. Optional: can be empty
Implementations
Sourceimpl JsGetActiveContractsPageResponse
impl JsGetActiveContractsPageResponse
pub fn new( active_contracts: Vec<JsGetActiveContractsResponse>, active_at_offset: i64, ) -> JsGetActiveContractsPageResponse