pub struct JsGetActiveContractsResponse {
pub workflow_id: Option<String>,
pub contract_entry: Option<Box<JsContractEntry>>,
pub stream_continuation_token: Option<String>,
}Fields
workflow_id: Option<String>The workflow ID used in command submission which corresponds to the contract_entry. Only set if the workflow_id for the command was set. Must be a valid LedgerString (as described in value.proto). Optional
contract_entry: Option<Box<JsContractEntry>>stream_continuation_token: Option<String>Opaque representation of a continuation token which can be used in the request to bypass the already processed part of the active contracts snapshot. Only populated for the streaming GetActiveContracts rpc call. Optional: can be empty
Implementations
Sourceimpl JsGetActiveContractsResponse
impl JsGetActiveContractsResponse
pub fn new() -> JsGetActiveContractsResponse