pub struct JsReassignment {
pub update_id: String,
pub command_id: String,
pub workflow_id: String,
pub offset: i64,
pub events: Option<Vec<JsReassignmentEvent>>,
pub trace_context: Option<Box<TraceContext>>,
pub record_time: String,
}Expand description
JsReassignment : Complete view of an on-ledger reassignment.
Fields
update_id: StringAssigned by the server. Useful for correlating logs. Must be a valid LedgerString (as described in value.proto). Required
command_id: StringThe ID of the command which resulted in this reassignment. Missing for everyone except the submitting party on the submitting participant. Must be a valid LedgerString (as described in value.proto). Optional
workflow_id: StringThe workflow ID used in reassignment command submission. Only set if the workflow_id for the command was set. Must be a valid LedgerString (as described in value.proto). Optional
offset: i64The participant’s offset. The details of this field are described in community/ledger-api/README.md. Required, must be a valid absolute offset (positive integer).
events: Option<Vec<JsReassignmentEvent>>The collection of reassignment events. Required.
trace_context: Option<Box<TraceContext>>record_time: StringThe time at which the reassignment was recorded. The record time refers to the source/target synchronizer for an unassign/assign event respectively. Required
Implementations