pub struct JsTransaction {
pub update_id: String,
pub command_id: String,
pub workflow_id: String,
pub effective_at: String,
pub events: Option<Vec<Event>>,
pub offset: i64,
pub synchronizer_id: String,
pub trace_context: Option<Box<TraceContext>>,
pub record_time: String,
}Expand description
JsTransaction : Filtered view of an on-ledger transaction’s create and archive events.
Fields
update_id: StringAssigned by the server. Useful for correlating logs. Must be a valid LedgerString (as described in value.proto). Required
command_id: StringThe ID of the command which resulted in this transaction. Missing for everyone except the submitting party. Must be a valid LedgerString (as described in value.proto). Optional
workflow_id: StringThe workflow ID used in command submission. Must be a valid LedgerString (as described in value.proto). Optional
effective_at: StringLedger effective time. Required
events: Option<Vec<Event>>The collection of events. Contains: - CreatedEvent or ArchivedEvent in case of ACS_DELTA transaction shape - CreatedEvent or ExercisedEvent in case of LEDGER_EFFECTS transaction shape Required
offset: i64The absolute offset. The details of this field are described in community/ledger-api/README.md. Required, it is a valid absolute offset (positive integer).
synchronizer_id: StringA valid synchronizer id. Identifies the synchronizer that synchronized the transaction. Required
trace_context: Option<Box<TraceContext>>record_time: StringThe time at which the transaction was recorded. The record time refers to the synchronizer which synchronized the transaction. Required
Implementations