pub struct JsTransactionTree {
pub update_id: String,
pub command_id: Option<String>,
pub workflow_id: Option<String>,
pub effective_at: String,
pub offset: i64,
pub events_by_id: HashMap<String, TreeEvent>,
pub synchronizer_id: String,
pub trace_context: Option<Box<TraceContext>>,
pub record_time: String,
}Expand description
JsTransactionTree : Provided for backwards compatibility, it will be removed in the Canton version 3.5.0. Complete view of an on-ledger transaction.
Fields
update_id: StringAssigned by the server. Useful for correlating logs. Must be a valid LedgerString (as described in value.proto). Required
command_id: Option<String>The ID of the command which resulted in this transaction. Missing for everyone except the submitting party. Must be a valid LedgerString (as described in value.proto). Optional
workflow_id: Option<String>The workflow ID used in command submission. Only set if the workflow_id for the command was set. Must be a valid LedgerString (as described in value.proto). Optional
effective_at: StringLedger effective time. Required
offset: i64The absolute offset. The details of this field are described in community/ledger-api/README.md. Required, it is a valid absolute offset (positive integer).
events_by_id: HashMap<String, TreeEvent>synchronizer_id: StringA valid synchronizer id. Identifies the synchronizer that synchronized the transaction. Required
trace_context: Option<Box<TraceContext>>record_time: StringThe time at which the transaction was recorded. The record time refers to the synchronizer which synchronized the transaction. Required
Implementations
Sourceimpl JsTransactionTree
impl JsTransactionTree
Sourcepub fn new(
update_id: String,
effective_at: String,
offset: i64,
events_by_id: HashMap<String, TreeEvent>,
synchronizer_id: String,
record_time: String,
) -> JsTransactionTree
pub fn new( update_id: String, effective_at: String, offset: i64, events_by_id: HashMap<String, TreeEvent>, synchronizer_id: String, record_time: String, ) -> JsTransactionTree
Provided for backwards compatibility, it will be removed in the Canton version 3.5.0. Complete view of an on-ledger transaction.