pub struct PrefetchContractKey {
pub template_id: String,
pub contract_key: Option<Value>,
}Expand description
PrefetchContractKey : Preload contracts
Fields
template_id: StringThe template of contract the client wants to prefetch. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4. Required
contract_key: Option<Value>The key of the contract the client wants to prefetch. Required
Implementations