Module tree_event

Module tree_event 

Enums

TreeEvent
TreeEvent : Provided for backwards compatibility, it will be removed in the Canton version 3.5.0. Each tree event message type below contains a witness_parties field which indicates the subset of the requested parties that can see the event in question. Note that transaction trees might contain events with no witness parties, which were included simply because they were children of events which have witnesses. Provided for backwards compatibility, it will be removed in the Canton version 3.5.0. Each tree event message type below contains a witness_parties field which indicates the subset of the requested parties that can see the event in question. Note that transaction trees might contain events with no witness parties, which were included simply because they were children of events which have witnesses.