Vet1

Struct Vet1 

pub struct Vet1 {
    pub packages: Vec<VettedPackagesRef>,
    pub new_valid_from_inclusive: Option<String>,
    pub new_valid_until_exclusive: Option<String>,
}
Vet1 : Set vetting bounds of a list of packages. Packages that were not previously vetted have their bounds added, previous vetting bounds are overwritten.

Fields

packages: Vec<VettedPackagesRef>

Packages to be vetted. If a reference in this list matches more than one package, the change is considered ambiguous and the entire update request is rejected. In other words, every reference must match exactly one package. Required: must be non-empty

new_valid_from_inclusive: Option<String>

The time from which these packages should be vetted, prior lower bounds are overwritten. Optional

new_valid_until_exclusive: Option<String>

The time until which these packages should be vetted, prior upper bounds are overwritten. Optional

Implementations

Source

impl Vet1

pub fn new(packages: Vec<VettedPackagesRef>) -> Vet1

Set vetting bounds of a list of packages. Packages that were not previously vetted have their bounds added, previous vetting bounds are overwritten.