pub struct VettedPackage {
pub package_id: String,
pub valid_from_inclusive: Option<String>,
pub valid_until_exclusive: Option<String>,
pub package_name: Option<String>,
pub package_version: Option<String>,
}Expand description
VettedPackage : A package that is vetting on a given participant and synchronizer, modelled after VettedPackage in topology.proto <https://github.com/digital-asset/canton/blob/main/community/base/src/main/protobuf/com/digitalasset/canton/protocol/v30/topology.proto#L206>_, enriched with the package name and version.
Fields
package_id: StringPackage ID of this package Required
valid_from_inclusive: Option<String>The time from which this package is vetted. Empty if vetting time has no lower bound. Optional
valid_until_exclusive: Option<String>The time until which this package is vetted. Empty if vetting time has no upper bound. Optional
package_name: Option<String>Name of this package. Only available if the package has been uploaded to the current participant. Optional
package_version: Option<String>Version of this package. Only available if the package has been uploaded to the current participant. Optional
Implementations
Sourceimpl VettedPackage
impl VettedPackage
Sourcepub fn new(package_id: String) -> VettedPackage
pub fn new(package_id: String) -> VettedPackage
A package that is vetting on a given participant and synchronizer, modelled after VettedPackage in topology.proto <https://github.com/digital-asset/canton/blob/main/community/base/src/main/protobuf/com/digitalasset/canton/protocol/v30/topology.proto#L206>_, enriched with the package name and version.