pub struct VettedPackages {
pub packages: Vec<VettedPackage>,
pub participant_id: String,
pub synchronizer_id: String,
pub topology_serial: i32,
}Expand description
VettedPackages : The list of packages vetted on a given participant and synchronizer, modelled after VettedPackages in topology.proto <https://github.com/digital-asset/canton/blob/main/community/base/src/main/protobuf/com/digitalasset/canton/protocol/v30/topology.proto#L206>_. The list only contains packages that matched a filter in the query that originated it.
Fields
packages: Vec<VettedPackage>Sorted by package_name and package_version where known, and package_id as a last resort. Required: must be non-empty
participant_id: StringParticipant on which these packages are vetted. Required
synchronizer_id: StringSynchronizer on which these packages are vetted. Required
topology_serial: i32Serial of last VettedPackages topology transaction of this participant and on this synchronizer. Required
Implementations
Sourceimpl VettedPackages
impl VettedPackages
Sourcepub fn new(
packages: Vec<VettedPackage>,
participant_id: String,
synchronizer_id: String,
topology_serial: i32,
) -> VettedPackages
pub fn new( packages: Vec<VettedPackage>, participant_id: String, synchronizer_id: String, topology_serial: i32, ) -> VettedPackages
The list of packages vetted on a given participant and synchronizer, modelled after VettedPackages in topology.proto <https://github.com/digital-asset/canton/blob/main/community/base/src/main/protobuf/com/digitalasset/canton/protocol/v30/topology.proto#L206>_. The list only contains packages that matched a filter in the query that originated it.