pub struct VettedPackagesRef {
pub package_id: Option<String>,
pub package_name: Option<String>,
pub package_version: Option<String>,
}Expand description
VettedPackagesRef : A reference to identify one or more packages. A reference matches a package if its package_id matches the package’s ID, its package_name matches the package’s name, and its package_version matches the package’s version. If an attribute in the reference is left unspecified (i.e. as an empty string), that attribute is treated as a wildcard. At a minimum, package_id or the package_name must be specified. If a reference does not match any package, the reference is considered unresolved and the entire update request is rejected.
Fields
package_id: Option<String>Package’s package id must be the same as this field. Optional
package_name: Option<String>Package’s name must be the same as this field. Optional
package_version: Option<String>Package’s version must be the same as this field. Optional
Implementations
Sourceimpl VettedPackagesRef
impl VettedPackagesRef
Sourcepub fn new() -> VettedPackagesRef
pub fn new() -> VettedPackagesRef
A reference to identify one or more packages. A reference matches a package if its package_id matches the package’s ID, its package_name matches the package’s name, and its package_version matches the package’s version. If an attribute in the reference is left unspecified (i.e. as an empty string), that attribute is treated as a wildcard. At a minimum, package_id or the package_name must be specified. If a reference does not match any package, the reference is considered unresolved and the entire update request is rejected.