pub async fn post_v2_interactive_submission_executeandwait(
configuration: &Configuration,
js_execute_submission_and_wait_request: JsExecuteSubmissionAndWaitRequest,
) -> Result<ExecuteSubmissionAndWaitResponse, Error<PostV2InteractiveSubmissionExecuteandwaitError>>Expand description
Similar to ExecuteSubmission but synchronously wait for the completion of the transaction IMPORTANT: Relying on the response from this endpoint requires trusting the Participant Node to be honest. A malicious node could make a successfully committed request appeared failed and vice versa