pub struct CostEstimationHints {
pub disabled: Option<bool>,
pub expected_signatures: Option<Vec<ExpectedSignatures>>,
}Expand description
CostEstimationHints : Hints to improve cost estimation precision of a prepared transaction
Fields
disabled: Option<bool>Disable cost estimation Default (not set) is false Optional
expected_signatures: Option<Vec<ExpectedSignatures>>Details on the keys that will be used to sign the transaction (how many and of which type). Signature size impacts the cost of the transaction. If empty, the signature sizes will be approximated with threshold-many signatures (where threshold is defined in the PartyToKeyMapping of the external party), using keys in the order they are registered. Empty list is equivalent to not providing this field Optional: can be empty
Implementations
Sourceimpl CostEstimationHints
impl CostEstimationHints
Sourcepub fn new() -> CostEstimationHints
pub fn new() -> CostEstimationHints
Hints to improve cost estimation precision of a prepared transaction