Structs
- Event
Format - EventFormat : A format for events which defines both which events should be included and what data should be computed and included for them. Note that some of the filtering behavior depends on the
TransactionShape, which is expected to be specified alongside usages ofEventFormat.