pub struct GetPreferredPackagesRequest {
pub package_vetting_requirements: Vec<PackageVettingRequirement>,
pub synchronizer_id: Option<String>,
pub vetting_valid_at: Option<String>,
}Fields
package_vetting_requirements: Vec<PackageVettingRequirement>The package-name vetting requirements for which the preferred packages should be resolved. Generally it is enough to provide the requirements for the intended command’s root package-names. Additional package-name requirements can be provided when additional Daml transaction informees need to use package dependencies of the command’s root packages. Required: must be non-empty
synchronizer_id: Option<String>The synchronizer whose vetting state should be used for resolving this query. If not specified, the vetting states of all synchronizers to which the participant is connected are used. Optional
vetting_valid_at: Option<String>The timestamp at which the package vetting validity should be computed on the latest topology snapshot as seen by the participant. If not provided, the participant’s current clock time is used. Optional
Implementations
Sourceimpl GetPreferredPackagesRequest
impl GetPreferredPackagesRequest
pub fn new( package_vetting_requirements: Vec<PackageVettingRequirement>, ) -> GetPreferredPackagesRequest