pub struct JsReassignment {
pub update_id: String,
pub command_id: Option<String>,
pub workflow_id: Option<String>,
pub offset: i64,
pub events: Vec<JsReassignmentEvent>,
pub trace_context: Option<Box<TraceContext>>,
pub record_time: String,
pub synchronizer_id: String,
pub paid_traffic_cost: Option<i64>,
}Expand description
JsReassignment : Complete view of an on-ledger reassignment.
Fields
update_id: StringAssigned by the server. Useful for correlating logs. Must be a valid LedgerString (as described in value.proto). Required
command_id: Option<String>The ID of the command which resulted in this reassignment. Missing for everyone except the submitting party on the submitting participant. Must be a valid LedgerString (as described in value.proto). Optional
workflow_id: Option<String>The workflow ID used in reassignment command submission. Only set if the workflow_id for the command was set. Must be a valid LedgerString (as described in value.proto). Optional
offset: i64The participant’s offset. The details of this field are described in community/ledger-api/README.md. Must be a valid absolute offset (positive integer). Required
events: Vec<JsReassignmentEvent>The collection of reassignment events. Required: must be non-empty
trace_context: Option<Box<TraceContext>>record_time: StringThe time at which the reassignment was recorded. The record time refers to the source/target synchronizer for an unassign/assign event respectively. Required
synchronizer_id: StringA valid synchronizer id. Identifies the synchronizer that synchronized this Reassignment. Required
paid_traffic_cost: Option<i64>The traffic cost that this participant node paid for the corresponding (un)assignment request. Not set for transactions that were - initiated by another participant - initiated offline via the repair service - processed before the participant started serving traffic cost on the Ledger API - returned as part of a query filtering for a non submitting party Optional
Implementations
Sourceimpl JsReassignment
impl JsReassignment
Sourcepub fn new(
update_id: String,
offset: i64,
events: Vec<JsReassignmentEvent>,
record_time: String,
synchronizer_id: String,
) -> JsReassignment
pub fn new( update_id: String, offset: i64, events: Vec<JsReassignmentEvent>, record_time: String, synchronizer_id: String, ) -> JsReassignment
Complete view of an on-ledger reassignment.