pub struct JsTransaction {
pub update_id: String,
pub command_id: Option<String>,
pub workflow_id: Option<String>,
pub effective_at: String,
pub events: Vec<Event>,
pub offset: i64,
pub synchronizer_id: String,
pub trace_context: Option<Box<TraceContext>>,
pub record_time: String,
pub external_transaction_hash: Option<String>,
pub paid_traffic_cost: Option<i64>,
}Expand description
JsTransaction : Filtered view of an on-ledger transaction’s create and archive events.
Fields
update_id: StringAssigned by the server. Useful for correlating logs. Must be a valid LedgerString (as described in value.proto). Required
command_id: Option<String>The ID of the command which resulted in this transaction. Missing for everyone except the submitting party. Must be a valid LedgerString (as described in value.proto). Optional
workflow_id: Option<String>The workflow ID used in command submission. Must be a valid LedgerString (as described in value.proto). Optional
effective_at: StringLedger effective time. Required
events: Vec<Event>The collection of events. Contains: - CreatedEvent or ArchivedEvent in case of ACS_DELTA transaction shape - CreatedEvent or ExercisedEvent in case of LEDGER_EFFECTS transaction shape Required: must be non-empty
offset: i64The absolute offset. The details of this field are described in community/ledger-api/README.md. It is a valid absolute offset (positive integer). Required
synchronizer_id: StringA valid synchronizer id. Identifies the synchronizer that synchronized the transaction. Required
trace_context: Option<Box<TraceContext>>record_time: StringThe time at which the transaction was recorded. The record time refers to the synchronizer which synchronized the transaction. Required
external_transaction_hash: Option<String>For transaction externally signed, contains the external transaction hash signed by the external party. Can be used to correlate an external submission with a committed transaction. Optional: can be empty
paid_traffic_cost: Option<i64>The traffic cost that this participant node paid for the confirmation request for this transaction. Not set for transactions that were - initiated by another participant - initiated offline via the repair service - processed before the participant started serving traffic cost on the Ledger API - returned as part of a query filtering for a non submitting party Optional
Implementations