pub struct ListVettedPackagesRequest {
pub package_metadata_filter: Option<Box<PackageMetadataFilter>>,
pub topology_state_filter: Option<Box<TopologyStateFilter>>,
pub page_token: Option<String>,
pub page_size: Option<i32>,
}Fields
package_metadata_filter: Option<Box<PackageMetadataFilter>>topology_state_filter: Option<Box<TopologyStateFilter>>page_token: Option<String>Pagination token to determine the specific page to fetch. Using the token guarantees that VettedPackages on a subsequent page are all greater (VettedPackages are sorted by synchronizer ID then participant ID) than the last VettedPackages on a previous page. The server does not store intermediate results between calls chained by a series of page tokens. As a consequence, if new vetted packages are being added and a page is requested twice using the same token, more packages can be returned on the second call. Leave unspecified (i.e. as empty string) to fetch the first page. Optional
page_size: Option<i32>Maximum number of VettedPackages results to return in a single page. If the page_size is unspecified (i.e. left as 0), the server will decide the number of results to be returned. If the page_size exceeds the maximum supported by the server, an error will be returned. To obtain the server’s maximum consult the PackageService descriptor available in the VersionService. Optional
Implementations
Sourceimpl ListVettedPackagesRequest
impl ListVettedPackagesRequest
pub fn new() -> ListVettedPackagesRequest