pub struct UpdateVettedPackagesRequest {
pub changes: Vec<VettedPackagesChange>,
pub dry_run: Option<bool>,
pub synchronizer_id: Option<String>,
pub expected_topology_serial: Option<Box<PriorTopologySerial>>,
pub update_vetted_packages_force_flags: Option<Vec<UpdateVettedPackagesForceFlags>>,
}Fields
changes: Vec<VettedPackagesChange>Changes to apply to the current vetting state of the participant on the specified synchronizer. The changes are applied in order. Any package not changed will keep their previous vetting state. Required: must be non-empty
dry_run: Option<bool>If dry_run is true, then the changes are only prepared, but not applied. If a request would trigger an error when run (e.g. TOPOLOGY_DEPENDENCIES_NOT_VETTED), it will also trigger an error when dry_run. Use this flag to preview a change before applying it. Defaults to false. Optional
synchronizer_id: Option<String>If set, the requested changes will take place on the specified synchronizer. If synchronizer_id is unset and the participant is only connected to a single synchronizer, that synchronizer will be used by default. If synchronizer_id is unset and the participant is connected to multiple synchronizers, the request will error out with PACKAGE_SERVICE_CANNOT_AUTODETECT_SYNCHRONIZER. Optional
expected_topology_serial: Option<Box<PriorTopologySerial>>update_vetted_packages_force_flags: Option<Vec<UpdateVettedPackagesForceFlags>>Controls whether potentially unsafe vetting updates are allowed. Optional: can be empty
Implementations
Sourceimpl UpdateVettedPackagesRequest
impl UpdateVettedPackagesRequest
pub fn new(changes: Vec<VettedPackagesChange>) -> UpdateVettedPackagesRequest